@@ -133,6 +133,11 @@ def new_project(
             raise_error(
                 f"Could not detect Git repo URL from existing repo: {e}"
             )
+        # We don't have a project name but do have a Git repo URL, the
+        # project name will be the Git repo name lowercased, since that's
+        # how the Calkit Cloud will create the project name by default
+        if name is None and git_repo_url is not None:
+            name = git_repo_url.split("/")[-1].lower()
         # If this isn't a DVC repo, run `dvc init`
         if not os.path.isfile(os.path.join(abs_path, ".dvc", "config")):
             typer.echo("Initializing DVC repository")
@@ -506,7 +511,14 @@ def new_question(
 def new_notebook(
     path: Annotated[str, typer.Argument(help="Notebook path (relative)")],
     title: Annotated[str, typer.Option("--title")],
-    description: Annotated[str, typer.Option("--description")] = None,
+    description: Annotated[str | None, typer.Option("--description")] = None,
+    stage_name: Annotated[
+        str | None,
+        typer.Option(
+            "--stage",
+            help="Name of the pipeline stage that runs this notebook.",
+        ),
+    ] = None,
     commit: Annotated[bool, typer.Option("--commit")] = False,
 ):
     """Add a new notebook."""
@@ -516,8 +528,7 @@ def new_notebook(
         raise ValueError("Path is not a file")
     if not path.endswith(".ipynb"):
         raise ValueError("Path does not have .ipynb extension")
-    # TODO: Add option to create stages that run `calkit nb clean` and
-    # `calkit nb execute`
+    # TODO: Add option to create stage if one doesn't exist
     ck_info = calkit.load_calkit_info()
     notebooks = ck_info.get("notebooks", [])
     paths = [f.get("path") for f in notebooks]
@@ -526,6 +537,12 @@ def new_notebook(
     obj = dict(path=path, title=title)
     if description is not None:
         obj["description"] = description
+    if stage_name is not None:
+        if stage_name not in ck_info.get("pipeline", {}).get("stages", {}):
+            raise ValueError(
+                f"Stage '{stage_name}' does not exist in the pipeline"
+            )
+        obj["stage"] = stage_name
     notebooks.append(obj)
     ck_info["notebooks"] = notebooks
     with open("calkit.yaml", "w") as f:
@@ -533,7 +550,7 @@ def new_notebook(
     if commit:
         repo = git.Repo()
         repo.git.add("calkit.yaml")
-        repo.git.commit(["-m", f"Add notebook {path}"])
+        repo.git.commit(["calkit.yaml", "-m", f"Add notebook {path}"])
 
 
 @new_app.command("docker-env")
@@ -574,6 +591,30 @@ def new_docker_env(
             "--add-layer", help="Add a layer (options: miniforge, foampy)."
         ),
     ] = [],
+    env_vars: Annotated[
+        list[str],
+        typer.Option(
+            "--env-var", help="Environment variables to set in the container."
+        ),
+    ] = [],
+    gpus: Annotated[str | None, typer.Option("--gpus")] = None,
+    args: Annotated[
+        list[str],
+        typer.Option(
+            "--arg",
+            help="Arguments to use when running container.",
+        ),
+    ] = [],
+    deps: Annotated[
+        list[str],
+        typer.Option(
+            "--dep",
+            help=(
+                "Path to add as a dependency, i.e., "
+                "a file that gets added to the container."
+            ),
+        ),
+    ] = [],
     wdir: Annotated[
         str, typer.Option("--wdir", help="Working directory.")
     ] = "/work",
@@ -587,6 +628,16 @@ def new_docker_env(
         str | None,
         typer.Option("--platform", help="Which platform(s) to build for."),
     ] = None,
+    ports: Annotated[
+        list[str],
+        typer.Option(
+            "--port",
+            help=(
+                "Ports to expose in the container, e.g., '8080:80'. "
+                "Can be specified multiple times."
+            ),
+        ),
+    ] = [],
     description: Annotated[
         str | None, typer.Option("--description", help="Description.")
     ] = None,
@@ -615,8 +666,11 @@ def new_docker_env(
     if path is not None and base and os.path.isfile(path) and not overwrite:
         raise_error("Output path already exists (use -f to overwrite)")
     if image_name is None:
-        typer.echo("No image name specified; using environment name")
-        image_name = name
+        typer.echo(
+            "No image name specified; using project and environment name"
+        )
+        _, project_name = calkit.detect_project_name().split("/")
+        image_name = f"{project_name}-{name}"
     repo = git.Repo()
     if base and path is not None:
         txt = "FROM " + base + "\n\n"
@@ -658,6 +712,21 @@ def new_docker_env(
         env["platform"] = platform
     if user:
         env["user"] = user
+    if gpus:
+        env["gpus"] = gpus
+    if env_vars:
+        env["env_vars"] = {}
+        for var in env_vars:
+            if "=" not in var:
+                raise_error(f"Invalid environment variable format: {var}")
+            key, value = var.split("=", 1)
+            env["env_vars"][key] = value
+    if args:
+        env["args"] = args
+    if deps:
+        env["deps"] = deps
+    if ports:
+        env["ports"] = ports
     envs[name] = env
     ck_info["environments"] = envs
     with open("calkit.yaml", "w") as f:
@@ -1788,6 +1857,88 @@ def new_latex_stage(
     )
 
 
+class NotebookStorage(str, Enum):
+    git = "git"
+    dvc = "dvc"
+    none = None
+
+
+@new_app.command(name="jupyter-notebook-stage")
+def new_jupyter_notebook_stage(
+    name: StageArgs.name,
+    environment: StageArgs.environment,
+    notebook_path: Annotated[
+        str, typer.Option("--notebook-path", help="Path to notebook.")
+    ],
+    inputs: StageArgs.inputs = [],
+    outputs: StageArgs.outputs = [],
+    outs_git: StageArgs.outs_git = [],
+    outs_git_no_delete: StageArgs.outs_git_no_delete = [],
+    outs_no_delete: StageArgs.outs_no_delete = [],
+    outs_no_store: StageArgs.outs_no_store = [],
+    outs_no_store_no_delete: StageArgs.outs_no_store_no_delete = [],
+    html_storage: Annotated[
+        NotebookStorage,
+        typer.Option(
+            "--html-storage",
+            help=("In what system to store the HTML output of the notebook."),
+        ),
+    ] = NotebookStorage.dvc,
+    cleaned_ipynb_storage: Annotated[
+        NotebookStorage,
+        typer.Option(
+            "--cleaned-ipynb-storage",
+            help=(
+                "In what system to store the cleaned ipynb output of "
+                "the notebook."
+            ),
+        ),
+    ] = NotebookStorage.git,
+    executed_ipynb_storage: Annotated[
+        NotebookStorage,
+        typer.Option(
+            "--executed-ipynb-storage",
+            help=(
+                "In what system to store the executed ipynb output of "
+                "the notebook."
+            ),
+        ),
+    ] = NotebookStorage.dvc,
+    overwrite: StageArgs.overwrite = False,
+    no_check: StageArgs.no_check = False,
+    no_commit: StageArgs.no_commit = False,
+):
+    """Add a stage to the pipeline that runs a Jupyter notebook."""
+    ck_outs = _to_ck_outs(
+        outputs=outputs,
+        outs_git=outs_git,
+        outs_git_no_delete=outs_git_no_delete,
+        outs_no_delete=outs_no_delete,
+        outs_no_store=outs_no_store,
+        outs_no_store_no_delete=outs_no_store_no_delete,
+    )
+    try:
+        stage = calkit.models.pipeline.JupyterNotebookStage(
+            kind="jupyter-notebook",
+            environment=environment,
+            inputs=inputs,  # type: ignore
+            outputs=ck_outs,
+            notebook_path=notebook_path,
+            html_storage=html_storage.value,
+            cleaned_ipynb_storage=cleaned_ipynb_storage.value,
+            executed_ipynb_storage=executed_ipynb_storage.value,
+        )
+    except Exception as e:
+        raise_error(f"Invalid stage specification: {e}")
+    _save_stage(
+        stage=stage,
+        name=name,
+        overwrite=overwrite,
+        no_check=no_check,
+        no_commit=no_commit,
+    )
+
+
 @new_app.command(name="release")
 def new_release(
     name: Annotated[
