@@ -272,6 +272,7 @@ def test_new_stage(tmp_dir):
             "tex",
             "--image",
             "texlive/texlive:latest-full",
+            "--no-check",
         ]
     )
     subprocess.check_call(
@@ -450,6 +451,7 @@ def test_new_python_script_stage(tmp_dir):
             "--python",
             "3.13",
             "requests",
+            "--no-check",
         ]
     )
     subprocess.check_call(
@@ -524,6 +526,7 @@ def test_new_latex_stage(tmp_dir):
             "tex",
             "--image",
             "texlive/texlive:latest-full",
+            "--no-check",
         ]
     )
     subprocess.check_call(
@@ -545,7 +548,7 @@ def test_new_latex_stage(tmp_dir):
     pipeline = calkit.dvc.read_pipeline()
     assert pipeline["stages"]["build-paper"]["cmd"] == (
         "calkit xenv -n tex --no-check -- "
-        "latexmk -cd -interaction=nonstopmode -pdf paper.tex"
+        "latexmk -cd -interaction=nonstopmode -silent -synctex=1 -pdf paper.tex"
     )
     assert set(pipeline["stages"]["build-paper"]["deps"]) == set(
         ["paper.tex", ".calkit/env-locks/tex.json"]
@@ -567,6 +570,7 @@ def test_new_matlab_script_stage(tmp_dir):
             "matlab1",
             "--image",
             "mathworks/matlab:latest",
+            "--no-check",
         ]
     )
     subprocess.check_call(
